****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_t1t2_assignformats.sas  
*
* Created (mm/dd/yyyy): 12/29/2017
* Last modified: 12/26/2018
* Version: 1.3
*
*--------------------------------------------------------------------------------------------------
* PURPOSE: The macro creates formats and global macro variables.                                        
*  Program inputs:                                                                                   
*  	- Default columns 
* 
*  Program outputs:                                                                                                                                       
*  	- formats
*
*  PARAMETERS:                                                                       
*            
*  Programming Notes:                                                                                
*                                                                           
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*   1.1		  04/16/18	 	AP		Added additional default column (RawCodeCount)
*
*   1.2		  07/01/18	 	AP		Added covariate stratification
*
*   1.2		  12/26/18	 	AP		Changed macro name from ms_assignformats to ms_t1t2_assignformats
*
***************************************************************************************************;

%macro ms_t1t2_assignformats();

	%put =====> MACRO CALLED: ms_t1t2_assignformats v1.3;

	/*variables to be excluded*/
	%if %length(&exclude.) = 0 or &exclude. = 0 %then %do;
		data _null_;
			call symputx("rmvarlist", "' '");
		run;
	%end;
	%else %do;
		proc format library= work;
			value excludefmt
		 	%do i = 1 %to 13;
				&i. = "%scan(&contvars., &i, " ")"
			%end;
			;
		run;
		data _null_;
			format rmvarlist $200. ;
		 	%do excl = 1 %to %sysfunc(countw(&exclude.));
		 		value = put(input("%scan(&exclude., &excl.)", 8.0), excludefmt.);
				%if &excl. = 1 %then %do;
					rmvarlist = "'"||strip(value)||"'";
				%end;
				%else %do;
					rmvarlist = strip(rmvarlist)||",'"||strip(value)||"'";
				%end;
			%end;
			call symputx("rmvarlist", lowcase(rmvarlist));
		run;
	%end;	

	%put excluded ===>&exclude.;
	%put VARIABLES REMOVED FROM OUTPUT===>&rmvarlist.;

	/*order of the groups in the input file*/
	proc format library = work;
		 value $orderfmt
		 %do i = 1 %to &Num_allgroups.;
		 	"%scan(&allgroups.,&i., " ")" = &i.
		 %end;
		 ;
	run;
	/*order the variables for summary tables*/
	 proc format library = work;
	  value $varorderfmt
		%do i = 1 %to 27;
			"%scan(&allvars., &i., " ")" = &i.
		%end;
		;
	 run;

	/*Map level to categories*/
	data _t&type.strata;
		set infolder.&USERSTRATA.;
		where strip(lowcase(tableid)) = "t&type.cida";
			levelvars = lowcase(levelvars);
			tableid = lowcase(tableID);
			levelvars = tranwrd(levelvars, "*", " ");
	run;
	
	%isdata(dataset=_t&type.strata);
	%let userlevelformat = ;
	%do lv = 1 %to &nobs.;
		data _null_;
			set _t&type.strata;
			if _n_ = &lv. then do;
				call symputx('levelid', strip(levelid));
				call symputx('levelvars', strip(propcase(levelvars)));
			end;
		run;

		%if %str(&levelvars) = %str() %then %let levelvars = %str( );
		%let userlevelformat = &userlevelformat. "&levelid." = "&levelvars.";
	%end;

	proc format library = work;
		value $levelfmt
		&userlevelformat.
         
		"M"   = "Male"
		"F"   = "Female"
		"O"   = "Other"

		"0"   = "Unknown"
		"1"   = "American Indian or Alaska Native"
		"2"   = "Asian"
		"3"   = "Black or African American"
		"4"   = "Native Hawaiian or Other Pacific Islander"
		"5"   = "White"

		"Y"   = "Hispanic Origin"
		"N"   = "Not Hispanic Origin"
		"U"   = "Unknown"

		"NE"  = "Northeast"
		"S"   = "South"
		"W"   = "West"
		"MW"  = "Midwest"
		;		
	run;
	
	/*Map numeric to Month name*/
	proc format library = work;  
 	value mn_name 
			   1='January'
               2='February'
               3='March'
               4='April'
               5='May'
               6='June'
               7='July'
               8='August'
               9='September'
              10='October'
              11='November'
              12='December'
           other='Invalid';
	run;

	/*age group formats*/
	%if %length(&agegroupfmt.) > 0 %then %do;
		proc format ;
			value $agefmt
				&agegroupfmt.;
		run;
	%end;

	/*Census order format*/
	proc format library = work;  
 	value $census_order 
			   'Northeast'='1'
               'Midwest'='2'
               'South'='3'
               'West'='4'
               'Invalid'='5'
               'Missing'='6'
               'Other'='7';
	run;

	/*HHS format*/
	proc format library = work;  
 	value $hhs_regionfMT 
			   '01'='HHS Region (01)'
               '02'='HHS Region (02)'
               '03'='HHS Region (03)'
               '04'='HHS Region (04)'
               '05'='HHS Region (05)'
               '06'='HHS Region (06)'
               '07'='HHS Region (07)'
               '08'='HHS Region (08)'
               '09'='HHS Region (09)'
               '10'='HHS Region (10)'
			   '11'='HHS Region (11)'
               'Invalid'='HHS Region (Invalid)'
               'Missing'='HHS Region (Missing)'
               'Other'='HHS Region (Other)';
	run;

	/*stratify by level*/
	data _null_;			
		%if %length(&stratify_by_level.) > 0 %then %do;
		%create_comma_charlist(inlist=&stratify_by_level., outlist=level_to_stratify);
			%do l = 1 %to %sysfunc(countw(&stratify_by_level.));
			 	category = put("%scan(&stratify_by_level., &l.)", $levelfmt.);
			 	if index(lowcase(category), "zip3") > 0 then 
					call symputx("zip3level", "zip3"); 
				if index(lowcase(category), "zip_uncertain") > 0 then 
					call symputx("zip_uncertain", "zip_uncertain"); 
			 	if index(lowcase(category), "state") > 0 then 
					call symputx("statelevel", "state");  
			 	if index(lowcase(category), "hhs_reg") > 0 then 
					call symputx("hhslevel", "hhs_reg");  
			 	if index(lowcase(category), "cb_reg") > 0 then 
					call symputx("cblevel", "cb_reg");  
				if index(lowcase(category), "race") > 0 then 
					call symputx("racelevel", "race");  
				if index(lowcase(category), "hispanic") > 0 then 
					call symputx("hispaniclevel", "hispanic");  
			%end;
		%end;
		%else %do;
			%let level_to_stratify = "000";
		%end;
	run; 

	/*Covariates*/
	%isdata(dataset=infolder.&covariatecodes.);
	%if %eval(&nobs.>0) & %str(&covarlist) ne %str() %then %do;
		%do cov = 1 %to %sysfunc(countw(&covarlist.));
			%let covarnum = %substr(%scan(&covarlist., &cov),6);

			%global covar&covarnum;
			data _null_;
				set infolder.&covariatecodes.(where=(covarnum = &covarnum.));
				if _n_ = 1 then do;
					call symputx("covar&covarnum.", studyname);
				end;
			run;
		%end;
	%end;

	%put =====> END MACRO: ms_t1t2_assignformats v1.3;

%mend ms_t1t2_assignformats;
