****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_t1t2_definegroupsruns.sas  
*
* Created (mm/dd/yyyy): 12/27/2017
* Last modified: 12/21/2018
* Version: 1.1
*
*--------------------------------------------------------------------------------------------------
* PURPOSE: The macro does the following 
*		  - creates format for exclude columns and for stratifications
*         - defines groups and runids
*                                        
*  Program inputs:                                                                                   
*  	- Default columns 
* 
*  Program outputs:                                                                                                                                       
*  	- formats
*
*  PARAMETERS:                                                                       
*            
*  Programming Notes:                                                                                
*                                                                           
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*   1.1		  12/21/18		AP		Modifications to integrate type 5 report
*									Changed macro name from ms_definegroupsruns to ms_t1t2_definegroupsruns
*
***************************************************************************************************;

%macro ms_t1t2_definegroupsruns();

	%put =====> MACRO CALLED: ms_t1t2_definegroupsruns v1.1;

	/*Make a new group variable for combined groups*/
	data &groupfile.;
		length combinegrouplabel $61;
	  	set infolder.&groupfile.;
	   if not missing(group1) and not missing(group2) then do;
	   	 combinegrouplabel = combinedgroupname;
	   end;
	   else  combinegrouplabel = strip(group1);
	   if grouplabel eq "" then grouplabel = combinegrouplabel;
	run;

	proc sort data = &groupfile.;
		by order;
	run;

	proc sql noprint;
		 select combinegrouplabel into: allgroups separated by ' '
		 from &groupfile. ;
		 select count(combinegrouplabel) into: Num_allgroups
		 from &groupfile.;
		 select grouplabel into: allgrouplabel separated by '|'
		 from &groupfile.;
		 select header into: header separated by ' '
		 from &groupfile.;
		 select coalesce(baselinelabel, grouplabel) into: allbaselinelabel separated by '|'
		 from &groupfile.;
	quit;

	%put allgroups ==> &allgroups.;
	%put numgroups ==> &Num_allgroups.;
	%put grouplabel ==> &allgrouplabel.;
	%put baselinelabel ==> &allbaselinelabel.;	 

	/*All run ids and groups for Group 1*/
	proc sql noprint;
		select runid1 into: T1runids  separated by ' ' 
		from infolder.&groupfile. where runid2 = "" ;
		select group1 into: T1GroupList separated by ' ' 
		from infolder.&groupfile. where runid2 = "";
	quit;
	%create_comma_charlist(inlist=&T1GroupList., outlist=T1GroupList_);

	%if "&T1GroupList." ne "" %then %do;
		%let NUM_T1runids = %sysfunc(countw(&T1runids.));
		%let NUM_T1Groups = %sysfunc(countw(&T1GroupList.));
	%end;
	%else %do;
		%let NUM_T1runids = 0;
		%let NUM_T1Groups = 0;
	%end;
		%put GROUP1===>;
		%put list of runids===>&T1runids.;
		%put number of runids===>&NUM_T1runids.;
		%put list of groups1===>&T1GroupList.;
		%put number of groups1===>&NUM_T1Groups.;

		/*All run ids and groups for Combined Group*/
		proc sql noprint;
			%do c = 1 %to 2;
				select strip(group&c.) into :combinegroup&c. separated by ' '
				from infolder.&groupfile. where runid1 ne "" and runid2 ne "";
				select strip(runid&c.) into :combinerun&c. separated by ' '
				from infolder.&groupfile. where runid1 ne "" and runid2 ne "";
			%end;
		quit;
		%if "&combinegroup1." ne "" %then %do;
		%let NUM_Crunids = %sysfunc(countw(&combinegroup1.));
		%end;

		%put Combined Groups===>;
		%put ==> runs with combine groups: (&NUM_Crunids.);
		%put ==> runids/groups for combined groups1: (&combinerun1. &combinegroup1.);
		%put ==> runids/groups for combined groups2: (&combinerun2. &combinegroup2.);
		%put;	
	
	
	/*All runids and their corresponding groups for group1 or combined groups*/
	proc sql noprint;
		create table group1 as
		 select distinct runid1 as runid, group1 as group from infolder.&groupfile. 
		 where runid1 ne "" ;
		create table combinedgroups as
		select distinct runid2 as runid, group2 as group from infolder.&groupfile. 
		where runid2 ne "" ;
	quit;
	data allgroups;
		 set group1 combinedgroups;
	run;
	proc sort nodupkey data = allgroups;
	by _all_;
	run;
	proc sql noprint;
		select count(distinct(runid)) into: numrunids from allgroups;
		select distinct(runid) into: runids separated by ' ' from allgroups;
	quit;
	%put &numrunids.;
	%put &runids.;
	
	%put =====> END MACRO: ms_t1t2_definegroupsruns v1.1;

%mend ms_t1t2_definegroupsruns;
